package jalview.gui;

import static org.testng.AssertJUnit.assertEquals;
import static org.testng.AssertJUnit.assertTrue;

import jalview.datamodel.DBRefEntry;
import jalview.datamodel.PDBEntry;
import jalview.datamodel.Sequence;
import jalview.datamodel.SequenceI;

import java.util.Vector;

import org.testng.annotations.AfterMethod;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

public class StructureChooserTest
{
  Sequence seq;

  @BeforeMethod(alwaysRun = true)
  public void setUp() throws Exception
  {
    seq = new Sequence("PDB|4kqy|4KQY|A", "ABCDEFGHIJKLMNOPQRSTUVWXYZ", 1,
            26);
    seq.setDatasetSequence(seq);
    for (int x = 1; x < 5; x++)
    {
      DBRefEntry dbRef = new DBRefEntry();
      dbRef.setAccessionId("XYZ_" + x);
      seq.addDBRef(dbRef);
    }

    PDBEntry dbRef = new PDBEntry();
    dbRef.setId("1tim");

    Vector<PDBEntry> pdbIds = new Vector<PDBEntry>();
    pdbIds.add(dbRef);

    seq.setPDBId(pdbIds);
  }

  @AfterMethod
  public void tearDown() throws Exception
  {
    seq = null;
  }

  @Test(groups = { "Functional" })
  public void buildQueryTest()
  {
    String query = StructureChooser.buildQuery(seq);
    System.out.println(">>>>>>>>>> query : " + query);
    assertEquals(
            "4kqy OR text:1tim OR text:XYZ_1 OR text:XYZ_2 OR text:XYZ_3 OR text:XYZ_4",
            query);
  }

  @Test(groups = { "Functional" })
  public void populateFilterComboBoxTest()
  {
    SequenceI[] selectedSeqs = new SequenceI[] { seq };
    StructureChooser sc = new StructureChooser(selectedSeqs, seq, null);
    sc.populateFilterComboBox();
    int optionsSize = sc.getCmbFilterOption().getItemCount();
    assertEquals(3, optionsSize); // if structures are not discovered then don't
                                  // populate filter options

    sc.setStructuresDiscovered(true);
    sc.populateFilterComboBox();
    optionsSize = sc.getCmbFilterOption().getItemCount();
    assertTrue(optionsSize > 3); // if structures are found, filter options
                                 // should be populated
  }

  @Test(groups = { "Functional" })
  public void fetchStructuresInfoTest()
  {
    SequenceI[] selectedSeqs = new SequenceI[] { seq };
    StructureChooser sc = new StructureChooser(selectedSeqs, seq, null);
    sc.fetchStructuresMetaData();
    assertTrue(sc.getDiscoveredStructuresSet() != null);
    assertTrue(sc.getDiscoveredStructuresSet().size() > 0);

  }
}
